@@ -82,7 +82,7 @@ source = codepipeline_actions.GitHubSourceAction(
     output=source_output,
     owner="myName",
     repo="myRepo",
-    oauth_token=cdk.SecretValue.plain_text("secret")
+    oauth_token=cdk.SecretValue.unsafe_plain_text("secret")
 )
 pipeline.add_stage(
     stage_name="source",
@@ -240,7 +240,7 @@ class PipelineDeployStackAction(
             output=source_output,
             owner="myName",
             repo="myRepo",
-            oauth_token=cdk.SecretValue.plain_text("secret")
+            oauth_token=cdk.SecretValue.unsafe_plain_text("secret")
         )
         pipeline.add_stage(
             stage_name="source",
@@ -520,7 +520,7 @@ class PipelineDeployStackActionProps:
                 output=source_output,
                 owner="myName",
                 repo="myRepo",
-                oauth_token=cdk.SecretValue.plain_text("secret")
+                oauth_token=cdk.SecretValue.unsafe_plain_text("secret")
             )
             pipeline.add_stage(
                 stage_name="source",
